# Generated by Django 5.0.3 on 2024-04-03 06:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoauthtoken', '0002_alter_token_refresh_token_alter_token_token'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tokenuser',
            name='email',
            field=models.EmailField(blank=True, max_length=254, verbose_name='email address'),
        ),
    ]
